==> vue-tab-item-2.8.0.tgz: package/lib/pc.js <==
import { defineComponent, $prefix, setup as _setup } from "@dft-vue-2-opentiny/vue-common";
import { renderless, api } from "@dft-vue-2-opentiny/vue-renderless/tab-item/vue";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  name: $prefix + "TabItem",
  componentName: "TabItem",
  props: {
    title: String,
    labelContent: Function,
    name: String,
    withClose: Boolean,
    disabled: Boolean,
    lazy: Boolean
  },
  setup: function setup(props, context) {
    return _setup({
      props,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return !_vm.lazy || _vm.state.loaded || _vm.state.active ? _c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.active,
      expression: "state.active"
    }],
    class: ["tiny-tab-pane", _vm.state.animateShow ? "active-item" : ""],
    attrs: {
      "aria-hidden": !_vm.state.active,
      "id": "pane-" + _vm.state.paneName,
      "aria-labelledby": "tab-" + _vm.state.paneName,
      "role": "tabpanel"
    }
  }, [_vm._t("default")], 2) : _vm._e();
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  pc as default
};

==> vue-tab-item-2.22.1.tgz: package/lib/pc.js <==
import { defineComponent, $prefix, setup } from '@opentinyvue/vue-common';
import { renderless, api } from '@opentinyvue/vue-renderless/tab-item/vue';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  name: $prefix + "TabItem",
  componentName: "TabItem",
  emits: ["tab-nav-update"],
  props: {
    title: String,
    name: String,
    withClose: Boolean,
    disabled: Boolean,
    lazy: Boolean
  },
  setup: function setup$1(props, context) {
    return setup({
      props,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return !_vm.lazy || _vm.state.loaded || _vm.state.active ? _c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.active,
      expression: "state.active"
    }],
    class: ["tiny-tab-pane", _vm.state.animateShow ? "active-item" : ""],
    attrs: {
      "aria-hidden": !_vm.state.active,
      "id": "pane-" + _vm.state.paneName,
      "aria-labelledby": "tab-" + _vm.state.paneName,
      "role": "tabpanel"
    }
  }, [_vm._t("default")], 2) : _vm._e();
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
